/**
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import {
    AccessControlActionType,
    SetDevelopVisibilityActionInterface,
    SetManageVisibilityActionInterface
} from "./types";

/**
 * Redux action to set the access control developer tab visibility.
 *
 * @param {boolean} visibility - visibility state
 * @return {SetHelpPanelDocsContentURLActionInterface} An action of type `SET_DEVELOPER_VISIBILITY`
 */
export const setDeveloperVisibility = (visibility: boolean): SetDevelopVisibilityActionInterface => ({
    payload: visibility,
    type: AccessControlActionType.SET_DEVELOPER_VISIBILITY
});

/**
 * Redux action to set the access control manage tab visibility.
 *
 * @param {boolean} visibility - visibility state
 * @return {SetHelpPanelDocsContentURLActionInterface} An action of type `SET_MANAGE_VISIBILITY`
 */
export const setManageVisibility = (visibility: boolean): SetManageVisibilityActionInterface => ({
    payload: visibility,
    type: AccessControlActionType.SET_MANAGE_VISIBILITY
});
